==> goods-center-biz-1.9.1-20170204.062920-1-sources.jar: cn/com/duiba/goods/center/biz/dao/item/ItemDao.java <==
/**
 * Project Name:goods-center-biz
 * File Name:ItemDao.java
 * Package Name:cn.com.duiba.goods.center.biz.dao
 * Date:2016年6月20日上午11:36:21
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.dao.item;

import java.util.Date;
import java.util.List;

import cn.com.duiba.goods.center.api.remoteservice.dto.item.ItemDto;
import cn.com.duiba.goods.center.biz.entity.ItemEntity;

/**
 * ClassName:ItemDao <br/>
 * Date:     2016年6月20日 上午11:36:21 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface ItemDao {

	/**
	 * 通过ID查询
	 * @param id
	 * @return
	 */
    public ItemEntity find(long id);

    /**
     * 获取活动链接券商品
     * @param ids
     * @return
     */
    public List<ItemEntity> findLinkActivityCouponItemsByIds(List<Long> ids);

    /**
     * 根据 ids 获取 list
     * @param ids
     * @return
     */
    public List<ItemEntity> findAllByIds(List<Long> ids);
    
	/**
	 * 创建商品
	 * 
	 * @param itemEntity
	 * @return
	 */
	public void insert(ItemEntity itemEntity);

	/**
	 * 修改商品
	 * 
	 * @param itemEntity
	 * @return
	 */
	public Integer update(ItemEntity itemEntity);

	/**
	 * 删除商品
	 * 
	 * @param itemId
	 * @return
	 */
	public Integer delete(Long itemId);

	/**
	 * 修改启用禁用
	 * 
	 * @param itemId
	 * @param enable
	 * @return
	 */
	public Integer updateEnable(Long itemId, Boolean enable);

	/**
	 * 减少一个库存
	 * @param itemId
	 * @return
	 */
	public Integer decrStock(Long itemId);
	
	/**
	 * 增加一个库存
	 * @param itemId
	 * @param bizId
	 * @return
	 */
	public Integer incrStock(Long itemId);
	
	/**
	 * 编辑商品，增加库存
	 * @param itemId
	 * @param number
	 * @return
	 */
	public Integer appendStock(Long itemId, Long number);
	
	/**
	 * 编辑商品，减少库存
	 * 
	 * @param itemId
	 * @param number
	 * @return
	 */
	public Integer deductStock(Long itemId, Long number);
	
	/**
	 * 修改库存和过期时间
	 * @param itemId
	 * @param totalStock
	 * @param validEndDate
	 * @return
	 */
	public int updateRemainingAndvalidEndDate(Long itemId, Long totalStock, Date validEndDate);
	
	/**
	 * 查询首页兑换项
	 * @param ids
	 * @return
	 */
	public List<ItemDto> findHomeItems(List<Long> ids);
}

==> goods-center-biz-1.9.7-20170227.111408-3-sources.jar: cn/com/duiba/goods/center/biz/dao/item/ItemDao.java <==
/**
 * Project Name:goods-center-biz
 * File Name:ItemDao.java
 * Package Name:cn.com.duiba.goods.center.biz.dao
 * Date:2016年6月20日上午11:36:21
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.biz.dao.item;

import java.util.Date;
import java.util.List;

import cn.com.duiba.goods.center.api.remoteservice.dto.item.ItemDto;
import cn.com.duiba.goods.center.biz.entity.ItemEntity;

/**
 * ClassName:ItemDao <br/>
 * Date:     2016年6月20日 上午11:36:21 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface ItemDao {

	/**
	 * 通过ID查询
	 * @param id
	 * @return
	 */
    public ItemEntity find(long id);

    /**
     * 获取活动链接券商品
     * @param ids
     * @return
     */
    public List<ItemEntity> findLinkActivityCouponItemsByIds(List<Long> ids);

    /**
     * 根据 ids 获取 list
     * @param ids
     * @return
     */
    public List<ItemEntity> findAllByIds(List<Long> ids);
    
	/**
	 * 创建商品
	 * 
	 * @param itemEntity
	 * @return
	 */
	public void insert(ItemEntity itemEntity);

	/**
	 * 修改商品
	 * 
	 * @param itemEntity
	 * @return
	 */
	public Integer update(ItemEntity itemEntity);

	/**
	 * 删除商品
	 * 
	 * @param itemId
	 * @return
	 */
	public Integer delete(Long itemId);

	/**
	 * 修改启用禁用
	 * 
	 * @param itemId
	 * @param enable
	 * @return
	 */
	public Integer updateEnable(Long itemId, Boolean enable);

	/**
	 * 减少一个库存
	 * @param itemId
	 * @return
	 */
	public Integer decrStock(Long itemId);
	
	/**
	 * 增加一个库存
	 * @param itemId
	 * @param bizId
	 * @return
	 */
	public Integer incrStock(Long itemId);
	
	/**
	 * 编辑商品，增加库存
	 * @param itemId
	 * @param number
	 * @return
	 */
	public Integer appendStock(Long itemId, Long number);
	
	/**
	 * 编辑商品，减少库存
	 * 
	 * @param itemId
	 * @param number
	 * @return
	 */
	public Integer deductStock(Long itemId, Long number);
	
	/**
	 * 修改库存和过期时间
	 * @param itemId
	 * @param totalStock
	 * @param validEndDate
	 * @return
	 */
	public int updateRemainingAndvalidEndDate(Long itemId, Long totalStock, Date validEndDate);
	
	/**
	 * 查询首页兑换项
	 * @param ids
	 * @return
	 */
	public List<ItemDto> findHomeItems(List<Long> ids);
	
	/**
	 * 根据Type查询，只用户查询几个兑吧固定直冲类商品
	 * @param type
	 * @return
	 */
	public ItemEntity findByType(String type);
	
	/**
	 * 查询JSONVALUE
	 * @param id
	 * @param key
	 * @return
	 */
	public String getJsonValue(Long id, String key);
	/**
	 * 设置JSONVALUE
	 * @param id
	 * @param key
	 * @param value
	 * @return
	 */
    public Integer setJsonValue(Long id, String value);
    /**
     * 查询JSONVALUE for update
     * @param id
     * @return
     */
    public String findJson4Update(Long id);

}
